#' 84149 Land-Use Changes Within Last 10 Years, Within 0.25 Mile Of Well (Codes)
#'
#' A table containing the USGS Land-Use Changes Within Last 10 Years, Within
#' 0.25 Mile Of Well (Codes) parameter codes.
#'
#' @format A data frame with 4 rows and 3 variables:
#' \describe{
#' \item{Parameter Code}{USGS Parameter Code}
#' \item{Fixed Value}{Fixed Value}
#' \item{Fixed Text}{Fixed Text}
#' }
#'
#'
#' @references
#' This data is from Table 26. Parameter codes with fixed values (USGS Water Quality Samples for USA: Sample Data). See \url{https://help.waterdata.usgs.gov/codes-and-parameters/}.
#'
#'
#'
#'
"pmcode_84149"
#> [1] "pmcode_84149"
